define(['app','hbs!js/book/init','hbs!js/book/infinite','js/book/service'],function(App, InitView, InfiniteView, Service){
	
	var bindings = [{
		element: '.page[data-page="book"]',
		selector: '.sort-item',
		event: 'click',
		handler: setBookSort
	},{
		element: '.page[data-page="book"]',
		selector: '.infinite-scroll',
		event: 'infinite',
		handler: getInfiniteInfo
	},{
		element: '.page[data-page="book"]',
		selector: '.book-item',
		event: 'click',
		handler: openThisPage
	}];
	
	var bookId;
	var sortId;
	var pageId;
	
	function init(query){
		if(!query.bookId)
		return;
		
		sortId = 0;
		bookId = query.bookId;	
		
		getInitInfo();
		App.utils.bindEvents(bindings);
	}
	
	function setBookSort(){
		App.utils.scrollTop();
		
		$$('.page[data-page="book"]').find('.sort-item').removeClass('current');
		$$(this).closest('.sort-item').addClass('current');
		$$('.page[data-page="book"]').find('.book-wrap').removeClass('module-loaded');	
		
		sortId = $$(this).data('sort-id');
		getInitInfo();
	}
	
	function getInitInfo(){
		pageId = 2;
		
		var container = $$('.page[data-page="book"]');
		var loading = container.find('.infinite-scroll');
		loading.data('on',false);
		
		t7.showIndicator();
		t7.attachInfiniteScroll(loading);
		
		Service.getInitInfo(bookId, sortId, function(response){
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});		
	}
	
	function getInfiniteInfo(){
		var container = $$('.page[data-page="book"]');
		var loading = container.find('.infinite-scroll');
		if(loading.data('on')) return;
		
		loading.data('on',true);
		App.utils.showPreloader(container);

		Service.getInfiniteInfo(bookId, pageId, sortId, function(response){
			setTimeout(function(){
				if(response.length == 0){
					t7.detachInfiniteScroll(loading);
					App.utils.hidePreloader(container);	
				}else{
					pageId = pageId + 1;	
					renderInfiniteInfo(response);
					loading.data('on',false);
				}		
			},500);
		});	
	}
	
	function renderInitInfo(response){
		var output = {};
		output.book_info = response.book_info;
		output.book_list = response.book_list;
		
		var content = InitView(output);
		$$('.book-title').html(response.book_info.name);
		
		var container = $$('.page[data-page="book"]');
		container.find('.book-wrap').html(content);
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function renderInfiniteInfo(response){
		var output = {};
		output.book_list = response;
		
		var content = InfiniteView(output);
		var container = $$('.page[data-page="book"]');
		container.find('.book-wrap').append(content);
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
	}
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			new Masonry('.page[data-page="book"] .book-wrap',{ 
				itemSelector:'.book-item',
				resize:false
			});	
			//Start toolbar
			App.utils.startToolbar();
		});	
		
		//Show Module wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();
			container.find('.book-wrap').addClass('module-loaded');				 
		});
	}
	
	function openThisPage(){
		var pageUrl = $$(this).data('url');
		App.utils.loadPage(pageUrl);	
	}
	
	return {
		init:init	
	};
	
});