define(["app",'hbs!js/home/init','hbs!js/home/infinite', 'js/home/service','js/mark'], function(App, InitView, InfiniteView, Service, Mark) {
															   
	var bindings = [{
		element: '#index',
		event: 'show',
		handler: initInfo
	},{
		element: '.user-tag',
		event: 'click',
		handler: userTagPage
	},{
		element: '.page[data-page="home"]',
		selector: '.search-bar',
		event: 'click',
		handler: openSearchPage
	},{
		element: '.page[data-page="home"]',
		selector: '.infinite-scroll',
		event: 'infinite',
		handler: getInfiniteInfo
	},{
		element: '.page[data-page="home"]',
		selector: '.pull-to-refresh-content',
		event: 'refresh',
		handler: getRefreshInfo
	},{
		element: '.page[data-page="home"]',
		selector: '.module-info',
		event: 'click',
		handler: openThisPage
	},{
		element: '.page[data-page="home"]',
		selector: '.share-button',
		event: 'click',
		handler: openSharePage
	},{
		element: '.page[data-page="home"]',
		selector: '.addto-button',
		event: 'click',
		handler: addPosts
	}];
	
	var pageId;
	
	function init(){		
		getInitInfo();
		App.utils.bindEvents(bindings);
	}
	
	function initInfo(){
		//Init Masonry
		var msnry = new Masonry('.page[data-page="home"] .module-wrap',{ 
			itemSelector:'.module-item',
			resize:false
		});	
		msnry.layout();
		
		//Hide network and remove loaded
		$$('.not-network').hide();
		$$('img.lazy-fadein').removeClass('lazy-loaded');	
	}
		
	function getRefreshInfo(){		
		getInitInfo();
		t7.pullToRefreshDone();	
	}
	
	function getInitInfo(){
		//Init Page
		pageId = 2;	
		var container = $$('.page[data-page="home"]');
		var loading = container.find('.infinite-scroll');
		loading.data('on',false);
		
		t7.showIndicator();
		t7.attachInfiniteScroll(loading);
				
		var markId = Mark.getCurrentMarkId();
		Service.getInitInfo(markId, function(response){
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});
		
	}
	
	function getInfiniteInfo(){		
		var container = $$('.page[data-page="home"]');
		var loading = container.find('.infinite-scroll');
		if(loading.data('on')) return;
		
		loading.data("on",true);
		App.utils.showPreloader(container);
		
		var markId = Mark.getCurrentMarkId();
		Service.getInfiniteInfo(markId, pageId, function(response){
			setTimeout(function(){
				if(response.length == 0){
					t7.detachInfiniteScroll(loading);
					App.utils.hidePreloader(container);
				}else{
					pageId = pageId + 1;	
					renderInfiniteInfo(response);
					loading.data("on",false);
				}	
			},300);
		});	
	}
	
	
	function renderInitInfo(response){
		var output = {};
		output.timeline = response;
		
		var content = InitView(output);
		var container = $$('.page[data-page="home"]');
		container.find('.module-wrap').html(content);
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function renderInfiniteInfo(response){		
		var output = {};
		output.timeline = response;
		
		var content = InfiniteView(output);
		var container = $$('.page[data-page="home"]');
		container.find('.module-wrap').append(content);
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
	}
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			var msnry = new Masonry('.page[data-page="home"] .module-wrap',{ 
				itemSelector:'.module-item',
				resize:false
			});	
		});	
		
		//Show Module wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();
			container.find('.module-wrap').addClass('module-loaded');
		});
	}
	
	function openThisPage(){
		var pageUrl = $$(this).data('url');
		App.utils.loadPage(pageUrl);
	}
	
	function openSearchPage(){
		var pageUrl = 'page/search.html';
		App.utils.loadPage(pageUrl);
	}
	
	function openSharePage(){		
		var response = {};
		var postsId = $$(this).parent().data('posts-id');
		
		response.typeId = '1';
		response.itemId = postsId;
		App.router.load('share',response);
	}
	
	function addPosts(){
		var markId = Mark.getCurrentMarkId();
		if(!markId || markId == ''){
			App.router.load('login');
			return;
		}
		
		var setButton = $$(this).find('.icon');
		var setCount = $$(this).parent().parent().find('.count');
		var postsId = $$(this).parent().data('posts-id');
		
		Service.addPosts(markId, postsId , function(response){
			if(response.status){
				setButton.removeClass('icon-add').addClass('icon-added');
			}else{
				setButton.removeClass('icon-added').addClass('icon-add');
			}
			setCount.text(response.fav_num);
		});
	}
	
	function userTagPage(){
		var markId = Mark.getCurrentMarkId();
		if(!markId || markId == ''){
			App.router.load('login');
			return;
		}
		
		var pageUrl = 'page/userlabel.html';
		App.utils.loadPage(pageUrl);	
	}
			
	return {
		init:init	
	};


});