define(['app','hbs!js/item/init','js/mark','js/item/service'],function(App, InitView, Mark, Service){
	
	var bindings = [{
		element: '.page[data-page="item"]',
		selector: '.book-item',
		event: 'click',
		handler: openThisPage
	},{
		element: '.page[data-page="item"]',
		selector: '.favor-button',
		event: 'click',
		handler: addFavorite
	},{
		element: '.page[data-page="item"]',
		selector: '.share-button',
		event: 'click',
		handler: openSharePage
	},{
		element: '.page[data-page="item"]',
		selector: '.button-web',
		event: 'click',
		handler: openWebPage
	},{
		element: '.page[data-page="item"]',
		selector: '.button-app',
		event: 'click',
		handler: openAppPage
	},{
		element: '.page[data-page="item"]',
		selector: '.shop',
		event: 'click',
		handler: openShopPage
	}];
	
	var itemId;
	var pageform;
	
	function init(query){
		if(!query.itemId)
		return;
		
		itemId = query.itemId;
		pageform = query.pageform;
		
		getInitInfo();
		App.utils.bindEvents(bindings);
	}
	
	function getInitInfo(){
		t7.showIndicator();	
		
		var markId = Mark.getCurrentMarkId();
		Service.getInitInfo(markId, itemId, function(response){
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});
	}
	
	function renderInitInfo(response){
		var output = {};
		output.item_info = response.item_info;
		output.item_list = response.item_list;
		
		var content = InitView(output);
		var container = $$('.page-on-center[data-page="item"]');
		container.find('.content-item').html(content);
		
		//ImageLoaded
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			new Masonry('.page-on-center[data-page="item"] .book-wrap',{ 
				itemSelector:'.book-item',
				resize:false
			});	
		});	
		
		//Show Module Wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();
			container.find('.module-cover').addClass('module-loaded');	
			container.find('.module-title').addClass('module-loaded');	
			container.find('.book-wrap').addClass('module-loaded');				 
		});
	}
	
	function addFavorite(){
		var markId = Mark.getCurrentMarkId();
		if(!markId || markId == ''){
			App.router.load('login');
			return;
		}
		
		var setButton = $$(this).find('.icon');
		var setCount = $$(this).parent().parent().find('.count');
		var itemId = $$(this).parent().data('item-id');
		
		Service.addFavorite(markId, itemId , function(response){
			if(response.status){
				setButton.removeClass('icon-favorite').addClass('icon-favorited');
			}else{
				setButton.removeClass('icon-favorited').addClass('icon-favorite');
			}
			setCount.text(response.fav_num);
		});
	}
	
	function openSharePage(){
		var response = {};
		response.typeId = '2';
		response.itemId = itemId;
		App.router.load('share',response);
	}
	
	function openThisPage(){
		var pageUrl = $$(this).data('url');
        App.utils.loadPage(pageUrl);
	}
	
	function openShopPage(){
		var shopId = $$(this).data('shop-id');
		var pageUrl = "page/shop.html?shopId=" + shopId;
        App.utils.loadPage(pageUrl);
	}
	
	//网页购买
	function openWebPage(){	
		var typeform = '1';
		var appInfo = Mark.getAppInfo();
		var markId = Mark.getCurrentMarkId();
		
		Service.shoppingInfo(itemId, markId, pageform, typeform, appInfo, function(response){
			var options = App.utils.getBrowserOptions('淘宝购买');
			cordova.ThemeableBrowser.open(response.click_url, '_blank', options);
		});	
	}
	
	//手淘购买
	function openAppPage(){
		var typeform = '2';
		var appInfo = Mark.getAppInfo();
		var markId = Mark.getCurrentMarkId();
		
		Service.shoppingInfo(itemId, markId, pageform, typeform, appInfo, function(response){																		 
			openTaobaoApp(response.click_url);
		});
	}
	
	//手淘应用
	function openTaobaoApp(clickUrl){
		var options = App.utils.getBrowserOptions('正在打开手淘...');
		var AppBrowser = cordova.ThemeableBrowser.open(clickUrl, '_blank', options);
	    AppBrowser.addEventListener('loadstart', function(response){
			if(App.utils.getTaobaoUrl(response.url)){
				var AppTaobao = startApp.set({
					"uri":response.url,
					"package":"com.taobao.taobao",
					"component": ["com.taobao.taobao","com.taobao.tao.detail.activity.DetailActivity"]
				});
				AppTaobao.start(function(){
					AppBrowser.close();
				},function(){
					//
				});
			} 
		});
	}
	
	return {
		init:init	
	};
	
});