define(['app','hbs!js/label/init','hbs!js/label/infinite', 'js/label/service','js/mark'],function(App, InitView, InfiniteView, Service, Mark){
	
	var bindings = [{
		element: '.page[data-page="label"]',
		selector: '.infinite-scroll',
		event: 'infinite',
		handler: getInfiniteInfo
	},{
		element: '.page[data-page="label"]',
		selector: '.fancy-button',
		event: 'click',
		handler: addFollow
	},{
		element: '.page[data-page="label"]',
		selector: '.addto-button',
		event: 'click',
		handler: addPosts
	},{
		element: '.page[data-page="label"]',
		selector: '.module-info',
		event: 'click',
		handler: openThisPage
	}];
		
	var tagId;
	var pageId;
	
	function init(query){
		if(!query.tagId)
		return;
		
		tagId = query.tagId;
		
		getInitInfo();
		App.utils.bindEvents(bindings);
	}
	
	function getRefreshInfo(){
		getInitInfo();
		t7.pullToRefreshDone();	
	}
	
	function getInitInfo(){
		pageId = 2;
		
		var container = $$('.page-on-center[data-page="label"]');
		var loading = container.find('.infinite-scroll');
		loading.data('on',false);
		
		t7.showIndicator();
		t7.attachInfiniteScroll(loading);
		
		var markId = Mark.getCurrentMarkId();
		Service.getInitInfo(markId, tagId, function(response){
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});
	}

	function getInfiniteInfo(){		
		var container = $$('.page-on-center[data-page="label"]');
		var loading = container.find('.infinite-scroll');
		if (loading.data('on')) return;
		
		loading.data('on',true);
		App.utils.showPreloader(container);
		
		var markId = Mark.getCurrentMarkId();
		Service.getInfiniteInfo(markId, tagId, pageId, function(response){
			setTimeout(function(){
				if(response.length == 0){
					t7.detachInfiniteScroll(loading);
					App.utils.hidePreloader(container);
				}else{
					pageId = pageId + 1;	
					renderInfiniteInfo(response);
					loading.data('on',false);
				}
			},500);
		});	
	}
	
	function renderInitInfo(response){
		var output = {};
		output.label_info = response.label_info;
		output.album_list = response.album_list;
		
		var content = InitView(output);
		$$('.tag-name').html(response.label_info.title);	
		
		var container = $$('.page-on-center[data-page="label"]');
		container.find('.label-wrap').html(content);
		
		//ImageLoaded
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function renderInfiniteInfo(response){
		var output = {};
		output.album_list = response;
		
		var content = InfiniteView(output);
		var container = $$('.page-on-center[data-page="label"]');
		container.find('.module-wrap').append(content);
		
		//ImageLoaded
		itemsLoad(container);
	}
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			new Masonry('.page-on-center[data-page="label"] .module-wrap',{ 
				itemSelector:'.module-item',
				resize:false
			});	
		});	
		
		//Show Module Wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();
			container.find('.module-cover').addClass('module-loaded');		
			container.find('.module-wrap').addClass('module-loaded');				 
		});
	}
	
	function addFollow(){
		var markId = Mark.getCurrentMarkId();
		if(!markId || markId == ''){
			App.router.load('login');
			return;
		}
		
		var setButton = $$(this).find('.icon');
		Service.addFollow(markId,tagId,function(response){
			if(response.status){
				setButton.removeClass('icon-follow').addClass('icon-followed');
			}else{
				setButton.removeClass('icon-followed').addClass('icon-follow');
			}
		});	
	}
	
	function addPosts(){
		var markId = Mark.getCurrentMarkId();
		if(!markId || markId == ''){
			App.router.load('login');
			return;
		}
		
		var setButton = $$(this).find('.icon');
		var setCount = $$(this).parent().parent().find('.count');
		var postsId = $$(this).parent().data('posts-id');
		
		Service.addPosts(markId, postsId , function(response){
			if(response.status){
				setButton.removeClass('icon-add').addClass('icon-added');
			}else{
				setButton.removeClass('icon-added').addClass('icon-add');
			}
			setCount.text(response.fav_num);
		});
	}
			
	function openThisPage(){
		var pageUrl = $$(this).data('url');
		App.utils.loadPage(pageUrl);
	}
	
	return {
		init:init	
	};
	
});