define(['app','hbs!js/posts/init','js/mark', 'js/posts/service'],function(App, InitView,Mark, Service){
	
	var bindings = [{
		element: '.page[data-page="posts"]',
		selector: '.share-button',
		event: 'click',
		handler: openSharePage
	},{
		element: '.page[data-page="posts"]',
		selector: '.favor-button',
		event: 'click',
		handler: addFavorite
	},{
		element: '.page[data-page="posts"]',
		selector: '.addto-button',
		event: 'click',
		handler: addPosts
	},{
		element: '.page[data-page="posts"]',
		selector: '.tag-link',
		event: 'click',
		handler: openLabelPage
	},{
		element: '.page[data-page="posts"]',
		selector: '.shop-link',
		event: 'click',
		handler: openShopPage
	},{
		element: '.page[data-page="posts"]',
		selector: '.posts-card',
		event: 'click',
		handler: openThisPage
	},{
		element: '.page[data-page="posts"]',
		selector: '.module-info',
		event: 'click',
		handler: openThisPage
	}];
	
	var postsId;
	
	function init(query){
		if(!query.postsId)
		return;
		
		postsId = query.postsId;
		
		getInitInfo();
		App.utils.bindEvents(bindings);
	}
		
	function getInitInfo(){
		t7.showIndicator();
		
		var markId = Mark.getCurrentMarkId();
		Service.getInitInfo(markId, postsId, function(response){
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});	
	}
	
	function renderInitInfo(response){
		var output = {};
		output.posts_info = response.posts_info;
		output.album_list = response.album_list;
		
		var content = InitView(output);
		var container = $$('.page-on-center[data-page="posts"]');
		container.find('.posts-wrap').html(content);
		
		//ImageLoaded
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			new Masonry('.page-on-center[data-page="posts"] .module-wrap',{ 
				itemSelector:'.module-item',
				resize:false
			});	
		});	
		
		//Show Module Wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();
			container.find('.module-cover').addClass('module-loaded');	
			container.find('.module-title').addClass('module-loaded');	
			container.find('.module-wrap').addClass('module-loaded');				 
		});
	}
	
	function openSharePage(){
		var response = {};
		response.typeId = '1';
		response.itemId = postsId;
		App.router.load('share',response);
	}
		
	function openThisPage(){
		var pageUrl = $$(this).data('url');
        App.utils.loadPage(pageUrl);
	}
	
	function openLabelPage(){
		var tagId = $$(this).data('tag-id');
		var pageUrl = "page/label.html?tagId=" + tagId;
        App.utils.loadPage(pageUrl);
	}
	
	function openShopPage(){
		var shopId = $$(this).data('shop-id');
		var pageUrl = "page/shop.html?shopId=" + shopId;
        App.utils.loadPage(pageUrl);	
	}
	
	function addFavorite(){
		var markId = Mark.getCurrentMarkId();
		if(!markId || markId == ''){
			App.router.load('login');
			return;
		}
		
		var setButton = $$(this).find('.icon');
		var setCount = $$(this).parent().parent().find('.count');
		var postsId = $$(this).parent().data('posts-id');
		
		Service.addFavorite(markId, postsId , function(response){
			if(response.status){
				setButton.removeClass('icon-favorite').addClass('icon-favorited');
			}else{
				setButton.removeClass('icon-favorited').addClass('icon-favorite');
			}
			setCount.text(response.fav_num);
		});
	}
	
	function addPosts(){
		var markId = Mark.getCurrentMarkId();
		if(!markId || markId == ''){
			App.router.load('login');
			return;
		}
		
		var setButton = $$(this).find('.icon');
		var setCount = $$(this).parent().parent().find('.count');
		var postsId = $$(this).parent().data('posts-id');
		
		Service.addFavorite(markId, postsId , function(response){
			if(response.status){
				setButton.removeClass('icon-add').addClass('icon-added');
			}else{
				setButton.removeClass('icon-added').addClass('icon-add');
			}
			setCount.text(response.fav_num);
		});
	}
		
	return {
		init:init	
	};
	
});