define(['app','hbs!js/searchgoods/init','hbs!js/searchgoods/infinite','js/searchgoods/service'],function(App, InitView, InfiniteView, Service){
	
	var bindings = [{
		element: '.page[data-page="searchgoods"]',
		selector: '.infinite-scroll',
		event: 'infinite',
		handler: getInfiniteInfo
	},{
		element: '.page[data-page="searchgoods"]',
		selector: '.book-item',
		event: 'click',
		handler: openThisPage
	}];
	
	var word;
	var pageId;
	
	function init(query){
		if(!query.word)
		return;
		
		word = query.word;	
		
		getInitInfo();
		App.utils.bindEvents(bindings);
	}
		
	function getInitInfo(){
		pageId = 2;
		
		var container = $$('.page[data-page="searchgoods"]');
		var loading = container.find('.infinite-scroll');
		loading.data('scrollLoading',false);
		
		t7.showIndicator();
		t7.attachInfiniteScroll(loading);
		
		Service.getInitInfo(word, function(response){
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});		
	}
	
	function getInfiniteInfo(){		
		var container = $$('.page[data-page="searchgoods"]');
		var loading = container.find('.infinite-scroll');
		if(loading.data('on')) return;
		
		loading.data('on',true);
		App.utils.showPreloader(container);
		
		Service.getInfiniteInfo(word, pageId, function(response){
			setTimeout(function(){
				if(response.length == 0){
					t7.detachInfiniteScroll(loading);
					App.utils.hidePreloader(container);
				}else{
					pageId = pageId + 1;	
					renderInfiniteInfo(response);
					loading.data('on',false);
				}
			},500);
		});	
	}
	
	function renderInitInfo(response){
		var output = {};
		output.book_list = response;
		
		var content = InitView(output);
		$$('.key-word-title').html(word);
		
		var container = $$('.page[data-page="searchgoods"]');
		container.find('.book-wrap').html(content);
				
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function renderInfiniteInfo(response){
		var output = {};
		output.book_list = response;
		
		var content = InfiniteView(output);
		var container = $$('.page[data-page="searchgoods"]');
		container.find('.book-wrap').append(content);
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
	}
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			new Masonry('.page[data-page="searchgoods"] .book-wrap',{ 
				itemSelector:'.book-item',
				resize:false
			});	
		});	
		
		//Show Module wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();	
			container.find('.book-wrap').addClass('module-loaded');				 
		});
	}
	
	function openThisPage(){
		var pageUrl = $$(this).data('url');
		App.utils.loadPage(pageUrl);	
	}
	
	return {
		init:init	
	};
	
});