define(['app','hbs!js/searchposts/init','hbs!js/searchposts/infinite','js/searchposts/service','js/mark'],function(App, InitView, InfiniteView, Service,Mark){
	
	var bindings = [{
		element: '.page[data-page="searchposts"]',
		selector: '.infinite-scroll',
		event: 'infinite',
		handler: getInfiniteInfo
	},{
		element: '.page[data-page="searchposts"]',
		selector: '.module-info',
		event: 'click',
		handler: openThisPage
	},{
		element: '.page[data-page="searchposts"]',
		selector: '.addto-button',
		event: 'click',
		handler: addPosts
	}];
	
	var word;
	var pageId;
	
	function init(query){
		if(!query.word)
		return;
		
		word = query.word;	
		
		getInitInfo();
		App.utils.bindEvents(bindings);
	}
		
	function getInitInfo(){
		pageId = 2;
		
		var container = $$('.page[data-page="searchposts"]');
		var loading = container.find('.infinite-scroll');
		loading.data('on',false);
		
		t7.showIndicator();
		t7.attachInfiniteScroll(loading);
		
		var markId = Mark.getCurrentMarkId();
		Service.getInitInfo(word, markId, function(response){
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});		
	}
	
	function getInfiniteInfo(){		
		var container = $$('.page[data-page="searchposts"]');
		var loading = container.find('.infinite-scroll');
		if(loading.data('on')) return;
		
		loading.data('on',true);
		App.utils.showPreloader(container);
		
		var markId = Mark.getCurrentMarkId();
		Service.getInfiniteInfo(word, pageId, markId, function(response){
			setTimeout(function(){
				if(response.length == 0){
					t7.detachInfiniteScroll(loading);
					App.utils.hidePreloader(container);
				}else{
					pageId = pageId + 1;	
					renderInfiniteInfo(response);
					loading.data('on',false);
				}
			},500);
		});	
	}
	
	function renderInitInfo(response){
		var output = {};
		output.album_list = response;
		
		var content = InitView(output);
		$$('.key-word-title').html(word);
		
		var container = $$('.page[data-page="searchposts"]');
		container.find('.module-wrap').html(content);
				
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function renderInfiniteInfo(response){
		var output = {};
		output.album_list = response;
		
		var content = InfiniteView(output);
		var container = $$('.page[data-page="searchposts"]');
		container.find('.module-wrap').append(content);
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
	}
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			new Masonry('.page[data-page="searchposts"] .module-wrap',{ 
				itemSelector:'.module-item',
				resize:false
			});
		});	
		
		//Show Module wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();	
			container.find('.module-wrap').addClass('module-loaded');				 
		});
	}
	
	function addPosts(){
		var markId = Mark.getCurrentMarkId();
		if(!markId || markId == ''){
			App.router.load('login');
			return;
		}
		
		var setButton = $$(this).find('.icon');
		var setCount = $$(this).parent().parent().find('.count');
		var postsId = $$(this).parent().data('posts-id');
		
		Service.addPosts(markId, postsId , function(response){
			if(response.status){
				setButton.removeClass('icon-add').addClass('icon-added');
			}else{
				setButton.removeClass('icon-added').addClass('icon-add');
			}
			setCount.text(response.fav_num);
		});
	}
	
	function openThisPage(){
		var pageUrl = $$(this).data('url');
		App.utils.loadPage(pageUrl);	
	}
	
	return {
		init:init	
	};
	
});