define(['app','hbs!js/shop/init','hbs!js/shop/infinite','js/shop/service'],function(App, InitView, InfiniteView, Service){
	
	var bindings = [{
		element: '.page[data-page="shop"]',
		selector: '.infinite-scroll',
		event: 'infinite',
		handler: getInfiniteInfo
	},{
		element: '.page[data-page="shop"]',
		selector: '.book-item',
		event: 'click',
		handler: openThisPage
	}];
	
	var shopId;
	var pageId;
	
	function init(query){
		if(!query.shopId)
		return;
		
		shopId = query.shopId;	
		
		getInitInfo();
		App.utils.bindEvents(bindings);
	}
	
	
	function getInitInfo(){
		pageId = 2;
		
		var container = $$('.page-on-center[data-page="shop"]');
		var loading = container.find('.infinite-scroll');
		loading.data('on',false);
		
		t7.showIndicator();
		t7.attachInfiniteScroll(loading);
		
		Service.getInitInfo(shopId, function(response){
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});		
	}
	
	function getInfiniteInfo(){
		var container = $$('.page-on-center[data-page="shop"]');
		var loading = container.find('.infinite-scroll');
		if(loading.data('on')) return;
		
		loading.data('on',true);
		App.utils.showPreloader(container);

		Service.getInfiniteInfo(shopId, pageId, function(response){
			setTimeout(function(){
				if(response.length == 0){
					t7.detachInfiniteScroll(loading);
					App.utils.hidePreloader(container);	
				}else{
					pageId = pageId + 1;	
					renderInfiniteInfo(response);
					loading.data('on',false);
				}		
			},500);
		});	
	}
	
	function renderInitInfo(response){
		var output = {};
		output.shop_info = response.shop_info;
		output.book_list = response.book_list;
		
		var content = InitView(output);
		$$('.navbar-on-center .shop-name').html(response.shop_info.name);
		$$('.page-on-center .shop-goods-num').html(response.shop_info.goods_num);
		
		var container = $$('.page-on-center[data-page="shop"]');
		container.find('.book-wrap').html(content);
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function renderInfiniteInfo(response){
		var output = {};
		output.book_list = response;
		
		var content = InfiniteView(output);
		var container = $$('.page-on-center[data-page="shop"]');
		container.find('.book-wrap').append(content);
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
	}
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			new Masonry('.page-on-center[data-page="shop"] .book-wrap',{ 
				itemSelector:'.book-item',
				resize:false
			});	
			//Start toolbar
			App.utils.startToolbar();
		});	
		
		//Show Module wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();
			container.find('.book-wrap').addClass('module-loaded');				 
		});
	}
	
	function openThisPage(){
		var pageUrl = $$(this).data('url');
		App.utils.loadPage(pageUrl);	
	}
	
	return {
		init:init	
	};
	
});