define(['app','js/mark','hbs!js/user/init','hbs!js/user/infinite','js/user/service'], function(App, Mark, InitView, InfiniteView, Service) {
	
	var bindings = [{
		element: '.user-setting',
		event: 'click',
		handler: userSettingPage
	},{
		element: '.page[data-page="user"]',
		selector: '.pull-to-refresh-content',
		event: 'refresh',
		handler: getRefreshInfo
	},{
		element: '.page[data-page="user"]',
		selector: '.infinite-scroll',
		event: 'infinite',
		handler: getInfiniteInfo
	},{
		element: '.page[data-page="user"]',
		selector: '.user-goods',
		event: 'click',
		handler: openThisPage
	},{
		element: '.page[data-page="user"]',
		selector: '.user-posts',
		event: 'click',
		handler: openThisPage
	},{
		element: '.page[data-page="user"]',
		selector: '.user-label',
		event: 'click',
		handler: openThisPage
	},{
		element: '.page[data-page="user"]',
		selector: '.user-edit',
		event: 'click',
		handler: openThisPage
	},{
		element: '.page[data-page="user"]',
		selector: '.favlist-item',
		event: 'click',
		handler: openThisPage
	}];
	
	var pageId;
		
	function init(){
		isLogin();
		getInitInfo();
		App.utils.bindEvents(bindings);	
	}
	
	function isLogin(){
		var markId = Mark.getCurrentMarkId();
		if(!markId || markId == ''){
			App.router.load('welcome');
			return;	
		}	
	}
	
	function getRefreshInfo(){		
		getInitInfo();
		t7.pullToRefreshDone();	
	}
			
	function getInitInfo(){
		pageId = 2;
		
		var container = $$('.page[data-page="user"]');
		var loading = container.find('.infinite-scroll');
		loading.data('on',false);
		
		t7.showIndicator();
		t7.attachInfiniteScroll(loading);
		
		var markId = Mark.getCurrentMarkId();
		Service.getInitInfo(markId, function(response){
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});
	}
	
	function getInfiniteInfo(){		
		var container = $$('.page[data-page="user"]');
		var loading = container.find('.infinite-scroll');
		if(loading.data('on')) return;
		
		loading.data('on',true);
		App.utils.showPreloader(container);
		
		var markId = Mark.getCurrentMarkId();
		Service.getInfiniteInfo(markId, pageId, function(response){
			setTimeout(function(){
				if(response.length == 0) {
					t7.detachInfiniteScroll(loading);
					App.utils.hidePreloader(container);
					
				}else{
					pageId = pageId + 1;
					renderInfiniteInfo(response);
					loading.data('on',false);	
				}
			},500);
		});	
	}
	
	function renderInitInfo(response){
		var output = {};
		output.user_info = response.user_info;
		output.fav_list = response.fav_list;
		
		var content = InitView(output);
		var container = $$('.page[data-page="user"]');
		container.find('.user-wrap').html(content);
		
		if($$('.page[data-page="user"] .favlist-item').length == 0){
			container.find('.user-wrap .notice-content').show();
		}
				
		//Add ImageLoaded
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function renderInfiniteInfo(response){		
		var output = {};
		output.fav_list = response;
		
		var content = InfiniteView(output);
		var container = $$('.page[data-page="user"]');
		container.find('.user-favlist').append(content);
		
		//Add ImageLoaded AND Not Masonry
		itemsLoad(container);
	}
	
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			//Delete Masonry
		});	
		
		//Show Module wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();	
			container.find('.user-favlist').addClass('module-loaded');		
		});
	}
		
	function openThisPage(){
		var pageUrl = $$(this).data('url');
		App.utils.loadPage(pageUrl);
	}
	
	function userSettingPage(){
		var pageUrl = 'page/setting.html';
		App.utils.loadPage(pageUrl);	
	}
	
	return {
		init:init
	};



});