define(['app','hbs!js/usergoods/init','hbs!js/usergoods/infinite','js/mark', 'js/usergoods/service'], function(App, InitView, InfiniteView, Mark, Service) {
	
	var bindings = [{
		element: '.page[data-page="usergoods"]',
		selector: '.infinite-scroll',
		event: 'infinite',
		handler: getInfiniteInfo
	},{
		element: '.page[data-page="usergoods"]',
		selector: '.pull-to-refresh-content',
		event: 'refresh',
		handler: getRefreshInfo
	},{
		element: '.page[data-page="usergoods"]',
		selector: '.book-item',
		event: 'click',
		handler: openThisPage
	}];
	
	var pageId;
	
	function init(){	
		getInitInfo();
		App.utils.bindEvents(bindings);
	}
	
	function getRefreshInfo(){
		getInitInfo();
		t7.pullToRefreshDone();	
	}
	
	function getInitInfo(){
		pageId = 2;
		
		var container = $$('.page[data-page="usergoods"]');
		var loading = container.find('.infinite-scroll');
		loading.data('on',false);
		
		t7.showIndicator();
		t7.attachInfiniteScroll(loading);
		
		var markId = Mark.getCurrentMarkId();
		Service.getInitInfo(markId, function(response){	
			setTimeout(function(){
				renderInitInfo(response);
			},1000);
		});	
	}
	
	function getInfiniteInfo(){		
		var container = $$('.page[data-page="usergoods"]');
		var loading = container.find('.infinite-scroll');
		if(loading.data('on')) return;
		
		loading.data('on',true);
		App.utils.showPreloader(container);
		
		var markId = Mark.getCurrentMarkId();
		Service.getInfiniteInfo(markId, pageId, function(response){
			setTimeout(function(){
				if(response.length == 0) {
					t7.detachInfiniteScroll(loading);
					App.utils.hidePreloader(container);
				}else{
					pageId = pageId + 1;
					renderInfiniteInfo(response);
					loading.data('on',false);	
				}
			},500);
		});	
	}
	
	function renderInitInfo(response){
		var output = {};
		output.book_list = response;

		var content = InitView(output);
		var container = $$('.page[data-page="usergoods"]');
		container.find('.book-wrap').html(content);
				
		if(response.length == 0){
			container.find('.notice-content').show();
		}
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
		t7.initImagesLazyLoad(container);
	}
	
	function renderInfiniteInfo(response){
		var output = {};
		output.book_list = response;
		
		var content = InfiniteView(output);
		var container = $$('.page[data-page="usergoods"]');
		container.find('.book-wrap').append(content);
		
		//Add ImageLoaded AND Masonry
		itemsLoad(container);
	}
	
	function itemsLoad(container){
		var imgLoad = new imagesLoaded(container,function(){
			new Masonry('.page[data-page="usergoods"] .book-wrap',{ 
				itemSelector:'.book-item',
				resize:false
			});	
		});	
		
		//Show Module wrap after All Images Loaded
		imgLoad.on('always',function(){
			t7.hideIndicator();
			container.find('.book-wrap').addClass('module-loaded');				 
		});
	}
	
	function openThisPage(){
		var pageUrl = $$(this).data('url');
		App.utils.loadPage(pageUrl);
	}
		
	return {
		init:init	
	};
	
});